@@ -8,7 +8,7 @@ use std::{
 
 use crate::{
     serialization::{ArrayStreamInfo, Deferrable, Parseable, SingleItemStreamInfo, Skippable},
-    Error, Result,
+    Error, NameReference, ObjectImport, Result,
 };
 
 fn skip_string<R>(reader: &mut R) -> Result<()>
@@ -310,12 +310,6 @@ impl Skippable for UnrealEngineVersion {
     }
 }
 
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub struct NameReference {
-    pub index: u32,
-    pub number: Option<NonZeroU32>,
-}
-
 #[derive(Debug)]
 pub struct UnrealNameReference {}
 
@@ -339,15 +333,6 @@ impl Parseable for UnrealNameReference {
     }
 }
 
-#[derive(Debug)]
-pub struct ClassImport {
-    pub class_package: NameReference,
-    pub class_name: NameReference,
-    pub outer_index: i32,
-    pub object_name: NameReference,
-    pub package_name: Option<NameReference>,
-}
-
 #[derive(Debug)]
 pub struct UnrealClassImport {}
 
@@ -356,7 +341,7 @@ impl Deferrable for UnrealClassImport {
 }
 
 impl Parseable for UnrealClassImport {
-    type ParsedType = ClassImport;
+    type ParsedType = ObjectImport;
 
     fn parse_with_info_seekless<R>(
         reader: &mut R,
@@ -387,7 +372,7 @@ impl Deferrable for UnrealClassImportWithPackageName {
 }
 
 impl Parseable for UnrealClassImportWithPackageName {
-    type ParsedType = ClassImport;
+    type ParsedType = ObjectImport;
 
     fn parse_with_info_seekless<R>(
         reader: &mut R,
